@@ -1,4 +1,6 @@
 package POE::Component::SmokeBox::Uploads::RSS;
+$POE::Component::SmokeBox::Uploads::RSS::VERSION = '1.04';
+#ABSTRACT: Obtain uploaded CPAN modules via RSS.
 
 use strict;
 use warnings;
@@ -6,9 +8,6 @@ use Carp;
 use POE qw(Component::RSSAggregator Component::Client::HTTP);
 use HTTP::Request;
 use HTML::LinkExtor;
-use vars qw($VERSION);
-
-$VERSION = '1.02';
 
 sub spawn {
   my $package = shift;
@@ -52,9 +51,9 @@ sub _shutdown {
 sub _real_shutdown {
   my ($kernel,$self) = @_[KERNEL,OBJECT];
   $kernel->alias_remove( $_ ) for $kernel->alias_list();
-  $kernel->refcount_decrement( $self->{session_id}, __PACKAGE__ ) unless $self->{alias};  
+  $kernel->refcount_decrement( $self->{session_id}, __PACKAGE__ ) unless $self->{alias};
   $kernel->refcount_decrement( $self->{sender_id}, __PACKAGE__ );
-  $kernel->post( $self->{http_id}, 'shutdown' ) unless $self->{http_alias}; 
+  $kernel->post( $self->{http_id}, 'shutdown' ) unless $self->{http_alias};
   $kernel->post( $self->{rssagg}, 'shutdown' );
   return;
 }
@@ -153,10 +152,18 @@ sub _dispatch {
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 POE::Component::SmokeBox::Uploads::RSS - Obtain uploaded CPAN modules via RSS.
 
+=head1 VERSION
+
+version 1.04
+
 =head1 SYNOPSIS
 
   use strict;
@@ -202,7 +209,7 @@ Takes a number of parameters:
 
   'event', the event handler in your session where each new upload alert should be sent, mandatory;
   'session', optional if the poco is spawned from within another session;
-  
+
 The 'session' parameter is only required if you wish the output event to go to a different
 session than the calling session, or if you have spawned the poco outside of a session.
 
@@ -212,7 +219,7 @@ Returns an object.
 
 =head1 METHODS
 
-=over 
+=over
 
 =item C<session_id>
 
@@ -226,7 +233,7 @@ Terminates the component.
 
 =head1 INPUT EVENTS
 
-=over 
+=over
 
 =item C<shutdown>
 
@@ -236,23 +243,13 @@ Terminates the component.
 
 =head1 OUTPUT EVENTS
 
-An event will be triggered for each new CPAN upload. The event will have ARG0 set to the path of the 
+An event will be triggered for each new CPAN upload. The event will have ARG0 set to the path of the
 upload:
 
   B/BI/BINGOS/POE-Component-SmokeBox-Uploads-RSS-0.01.tar.gz
 
 Suitable for feeding to the smoke tester of your choice.
 
-=head1 AUTHOR
-
-Chris C<BinGOs> Williams <chris@bingosnet.co.uk>
-
-=head1 LICENSE
-
-Copyright E<copy> Chris Williams
-
-This module may be used, modified, and distributed under the same terms as Perl itself. Please see the license that came with your Perl distribution for details.
-
 =head1 SEE ALSO
 
 L<POE>
@@ -263,4 +260,15 @@ L<POE::Component::Client::HTTP>
 
 L<http://search.cpan.org/uploads.rdf>
 
+=head1 AUTHOR
+
+Chris Williams <chris@bingosnet.co.uk>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2017 by Chris Williams.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
